@@ -1,4 +1,4 @@
 from django_upgrade.main import main
 
 if __name__ == "__main__":  # pragma: no cover
-    exit(main())
+    raise SystemExit(main())
