@@ -10,7 +10,7 @@ from tokenize_rt import Offset
 
 from django_upgrade.ast import ast_start_offset
 from django_upgrade.data import Fixer, State, TokenFunc
-from django_upgrade.tokens import replace_arguments
+from django_upgrade.tokens import replace_argument_names
 
 fixer = Fixer(
     __name__,
@@ -32,19 +32,21 @@ def visit_Call(
     parent: ast.AST,
 ) -> Iterable[Tuple[Offset, TokenFunc]]:
     if (
-        isinstance(node.func, ast.Name)
-        and NAME in state.from_imports[MODULE]
-        and node.func.id == NAME
-        and any(k.arg in KWARGS for k in node.keywords)
-    ) or (
-        isinstance(node.func, ast.Attribute)
-        and node.func.attr == NAME
-        and "validators" in state.from_imports["django.core"]
-        and isinstance(node.func.value, ast.Name)
-        and node.func.value.id == "validators"
-    ):
+        (
+            isinstance(node.func, ast.Name)
+            and NAME in state.from_imports[MODULE]
+            and node.func.id == NAME
+        )
+        or (
+            isinstance(node.func, ast.Attribute)
+            and node.func.attr == NAME
+            and "validators" in state.from_imports["django.core"]
+            and isinstance(node.func.value, ast.Name)
+            and node.func.value.id == "validators"
+        )
+    ) and any(k.arg in KWARGS for k in node.keywords):
         yield ast_start_offset(node), partial(
-            replace_arguments,
+            replace_argument_names,
             node=node,
             arg_map=KWARGS,
         )
